pub struct CityBlock {
pub perimeter: Vec<NodeId>,
}Expand description
An enclosed city block bounded by road edges.
The perimeter is a closed polygon of node indices extracted by
crate::polygons::extract_blocks using the left-most-turn algorithm.
Blocks always wind clockwise (negative signed area).
Fields
perimeter: Vec<NodeId>Ordered list of node indices forming a closed polygon perimeter.